if select(2, UnitClass("player")) ~= "DEATHKNIGHT" then
   return
end

------------------------------------------------------------------------
local BarSize = {
	["height"] = 8,
	["width"] = 48,
};

local BarPos = {
	["blood"] = { ["x"] = 2, ["y"] = -2 },
	["unholy"] = { ["x"] = 2+(2*BarSize["width"] + 8), ["y"] = -2 },
	["frost"] = { ["x"] = 2+((4*BarSize["width"]) + 16), ["y"] = -2 },
	["rp"] = { ["x"] = 2, ["y"] = -16 },
};

TRB_Runes = CreateFrame("frame", nil, UIParent);

function TRB_Runes:SavePosition()
	TRB_Config["Positions"]["runes"] = { self:GetPoint() };
end

function TRB_Runes:LoadPosition()
	self:_SetPoint( unpack(TRB_Config["Positions"]["runes"]) );
end

function TRB_Runes:init()

	--DEFAULT_CHAT_FRAME:AddMessage("UT: module Runes Loaded");
	
	-- Create move frame
		f = CreateFrame("frame", nil, self);
		f.parent = self;
		f:SetAllPoints(self);
		self:SetMovable(true);
		f:EnableMouse(true);
		f:RegisterForDrag("LeftButton");
		f:SetScript("OnDragStart", function(frame) frame.parent:StartMoving() end );
		f:SetScript("OnDragStop", function(frame) frame.parent:StopMovingOrSizing(); frame.parent:SavePosition() end );
		
		f.bg = f:CreateTexture(nil, "ARTWORK");
		f.bg:SetAllPoints(f);
		f.bg:SetTexture(0.8,0.8,0.8, 0.4);
		f:SetFrameStrata("HIGH");
		f:Hide();
		
		self.moveFrame = f;
	-- Move frame done
	
	-- Set position
	self:SetWidth(BarSize["width"]*6+22)
	self:SetHeight(BarSize["height"]*2+10)
	self:SetPoint( unpack(TRB_Config["Positions"]["runes"]) );
	
	-- Background
	local bg = self:CreateTexture(nil, "BACKGROUND");
	bg:SetWidth(512);
	bg:SetHeight(512);
	bg:SetPoint("CENTER", self, "CENTER", 0, 0);
	bg:SetTexture("Interface\\AddOns\\ThreeRuneBars\\runes.tga");
	self.bg = bg;
	
	self.Bars = {};
	self.needUpdate = { [1] = false, [2] = false, [3] = false, [4] = false, [5] = false, [6] = false };

	-- Blood
	self.Bars[1] = self:CreateBar("TRB_blood1", self);
	self.Bars[1]:SetPoint("TOPLEFT", self, "TOPLEFT", BarPos["blood"]["x"], BarPos["blood"]["y"]);
	self.Bars[2] = self:CreateBar("TRB_blood2", self);
	self.Bars[2]:SetPoint("TOPLEFT", self.Bars[1], "TOPRIGHT", 2, 0);
	self:UpdateColor(1, 1);
	self:UpdateColor(2, 1);
	
	-- Unholy
	self.Bars[3] = self:CreateBar("TRB_unholy1", self);
	self.Bars[3]:SetPoint("TOPLEFT", self, "TOPLEFT", BarPos["unholy"]["x"], BarPos["unholy"]["y"]);
	self.Bars[4] = self:CreateBar("TRB_unholy2", self);
	self.Bars[4]:SetPoint("TOPLEFT", self.Bars[3], "TOPRIGHT", 2, 0);
	self:UpdateColor(3, 2);
	self:UpdateColor(4, 2);

	-- Frost
	self.Bars[5] = self:CreateBar("TRB_frost1", self);
	self.Bars[5]:SetPoint("TOPLEFT", self, "TOPLEFT", BarPos["frost"]["x"], BarPos["frost"]["y"]);
	self.Bars[6] = self:CreateBar("TRB_frost2", self);
	self.Bars[6]:SetPoint("TOPLEFT", self.Bars[5], "TOPRIGHT", 2, 0);
	self:UpdateColor(5, 3);
	self:UpdateColor(6, 3);
	
	-- Runic Power
	self.Bars[7] = self:CreateBar("TRB_RunicPower", self);
	self.Bars[7]:SetPoint("TOPLEFT", self, "TOPLEFT", BarPos["rp"]["x"], BarPos["rp"]["y"]);
	self.Bars[7]:SetWidth(306);
	self.Bars[7]:SetValue( UnitPower("player") );
	self.Bars[7]:SetMinMaxValues( 0, UnitPowerMax("player", 6) );
	self:UpdateColor(7, 7)
	
	--
	--  EVENTS
	--	
--	self:RegisterEvent("PLAYER_REGEN_ENABLED"); -- may be used for OOC fader
--	self:RegisterEvent("PLAYER_REGEN_DISABLED");
	-- Runes
	self:RegisterEvent("RUNE_POWER_UPDATE")
	self:RegisterEvent("RUNE_TYPE_UPDATE")
	-- Runic Power
	self:RegisterEvent("UNIT_POWER");
	self:RegisterEvent("UNIT_MAXPOWER");

	self.last = 0;
	self:SetScript("OnEvent", function(frame, event, ...) frame[event](frame, ...); end );
	self:SetScript("OnUpdate", function(frame, elapsed) frame:OnUpdate(elapsed); end );
end

function TRB_Runes:CreateBar(name, parent)
	local Bar = CreateFrame("StatusBar", name, parent);
	Bar:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar");
	Bar:GetStatusBarTexture():SetHorizTile(true);
	Bar:SetMinMaxValues(0, 100);
	Bar:SetValue(100);
	Bar:SetWidth(BarSize["width"]);
	Bar:SetHeight(BarSize["height"]);
	
	Bar.bg = Bar:CreateTexture(nil, "BACKGROUND");
	Bar.bg:SetAllPoints(Bar);
	Bar.bg:SetTexture(0,0,0, 0.5);

	return Bar;
end

function TRB_Runes:UpdateColor(r, t, faded)
	if( t == nil) then t=GetRuneType(r); end

	local a = 1;
	if( faded ) then
		a = 0.3;
	end
	self.Bars[r]:SetStatusBarColor(TRB_Config["Colors"][t][1], TRB_Config["Colors"][t][2], TRB_Config["Colors"][t][3], a);
end

function TRB_Runes:Updatebar( rune1, rune2 )
	local s1, d1, r1 = GetRuneCooldown(rune1);
	local s2, d2, r2 = GetRuneCooldown(rune2);
	local rt1 = GetRuneType(rune1);
	local rt2 = GetRuneType(rune2);
	
	local val1 = GetTime() - s1;
	local val2 = GetTime() - s2;
	if( r1 or val1 > d1) then
		val1 = d1;
	end
	if( r2 or val2 > d2) then
		val2 = d2;
	end
	if( val1 < 0 ) then val1 = 0 end
	if( val2 < 0 ) then val2 = 0 end
	
	val1 = (val1 / d1) * 100;
	val2 = (val2 / d2) * 100;
	
	if( val1 < val2 ) then
		self.Bars[rune1]:SetValue(val2);
		self.Bars[rune2]:SetValue(val1);
		
		self:UpdateColor(rune1, rt2, (val2 < 99));
		self:UpdateColor(rune2, rt1, (val1 < 99));
	else
		self.Bars[rune1]:SetValue(val1);
		self.Bars[rune2]:SetValue(val2);
		
		self:UpdateColor(rune1, rt1, (val1 < 99));
		self:UpdateColor(rune2, rt2, (val2 < 99));
	end
end

-- Runic Power EVENTS
function TRB_Runes:UNIT_POWER(unit, power)
	if( unit == "player" ) then
		local rp = UnitPower("player")
		--DEFAULT_CHAT_FRAME:AddMessage("RP: "..rp);
		self.Bars[7]:SetMinMaxValues( 0, UnitPowerMax("player", 6) );
		self.Bars[7]:SetValue(rp);
		--DEFAULT_CHAT_FRAME:AddMessage("bar: "..Bars[7]:GetValue());
	end
end

function TRB_Runes:UNIT_MAXPOWER(unit, power)
	self.Bars[7]:SetMinMaxValues( 0, UnitPowerMax("player", 6) );
end

-- Runes EVENTS
function TRB_Runes:RUNE_POWER_UPDATE(rune, useable)
	if( not useable ) then
		self.needUpdate[rune] = true;
	end
end

function TRB_Runes:RUNE_TYPE_UPDATE(rune)
	self:UpdateColor(rune);
end

-- OnUpdate
function TRB_Runes:OnUpdate(elapsed)
	self.last = self.last + elapsed;
	
	if( self.last > 0.01 ) then
		if( self.needUpdate[1] or self.needUpdate[2] ) then
			self:Updatebar( 1, 2); -- Blood
		end
		
		if( self.needUpdate[3] or self.needUpdate[4] ) then
			self:Updatebar( 3, 4); -- Unholy
		end
		
		if( self.needUpdate[5] or self.needUpdate[6] ) then
			self:Updatebar( 5, 6); -- Frost
		end
		
		self.last = 0;
	end
end

-- Register Rune module
ThreeRuneBars:RegisterModule("Runes", TRB_Runes);
